@@ -29,11 +29,12 @@ class SpikeSortingToolChain(object):
 
 
 # famillies
-filters = [ ButterworthFilter, ]
-detections = [  MedianThresholdDetection, StdThresholdDetection, ManualThresholdDetection, MTEODetection]
-waveforms = [ AlignWaveformOnDetection, AlignWaveformOnPeak ]
+filters = [ ButterworthFilter, DerivativeFilter, SlidingMedianFilter]
+detections = [  RelativeThresholdDetection, ManualThresholdDetection, MTEODetection]
+waveforms = [ AlignWaveformOnDetection, AlignWaveformOnPeak, AlignWaveformOnCentralWaveform ]
 features = [ PcaFeature, IcaFeature,CombineFeature, AllPeak, PeakToValley, HaarWaveletFeature]
 sorting = [SklearnGaussianMixtureEm, SklearnKMeans, SklearnMiniBatchKMeans, SklearnMeanShift ]
+clean = [OutsideTemplateCleaning, ]
 
 
 
@@ -47,6 +48,18 @@ class FromFullBandSignalToClustered(SpikeSortingToolChain):
                                             [ 'sorting', sorting],
                                             ])
 
+class FromFullBandSignalToClusteredClean(SpikeSortingToolChain):
+    name = 'from full band signal to clustered spike with clean'
+    chain = OrderedDict([
+                                            [ 'filters', filters],
+                                            [ 'detections', detections],
+                                            [ 'waveforms', waveforms],
+                                            [ 'features', features],
+                                            [ 'sorting', sorting],
+                                            [ 'clean', clean],
+                                            ])
+
+
 class FromFilteredBandSignalToClustered(SpikeSortingToolChain):
     name = 'from filtered band signal to clustered spike'
     chain = OrderedDict([
@@ -75,16 +88,7 @@ class FromFeatureToClustered(SpikeSortingToolChain):
 
 
 class FromFullBandSignalToDetection(SpikeSortingToolChain):
-    name = 'from full band signal to detected spike'    
-            
-            
-        
-        
-        
-
-
-
-
+    name = 'from full band signal to detected spike'
     chain = OrderedDict([
                                             [ 'filters', filters],
                                             [ 'detections', detections],
@@ -92,7 +96,7 @@ class FromFullBandSignalToDetection(SpikeSortingToolChain):
 
     
 
-all_toolchain = [FromFullBandSignalToClustered, FromFilteredBandSignalToClustered,
+all_toolchain = [FromFullBandSignalToClustered, FromFullBandSignalToClusteredClean, FromFilteredBandSignalToClustered,
                             FromWaveformToClustered, FromFeatureToClustered, FromFullBandSignalToDetection,
                             ]
 
@@ -290,6 +294,9 @@ class ToolChainWidget(QWidget):
         self.spikesorter.run_step(method, **kargs)
         print self.spikesorter
         print self.spikesorter.history[-1]
+        
+        if  method in sorting:
+            self.spikesorter.cluster_colors = { }
         self.need_refresh.emit()
     
     def run_all_chain(self):
