@@ -19,7 +19,9 @@ def threshold_detection_multi_channel_multi_segment( signals,
                                 thresholds, sign,
                                 consistent_across_channels, consistent_across_segments,
                                 threshold_mode,
-                                peak_span = None):
+                                peak_span = None,
+                                combined_sum = True,
+                                ):
     #~ print thresholds
     if consistent_across_channels:
         thresholds[:] = np.mean(thresholds, axis=0)[np.newaxis,:]
@@ -31,25 +33,29 @@ def threshold_detection_multi_channel_multi_segment( signals,
     spike_index_array = np.empty(signals.shape[1], dtype = object)
     
     for s in range(signals.shape[1]):
-        combined = [ ]
-        for c in range(signals.shape[0]):
-            sig = np.zeros(signals[c, s].size, dtype = signals[c, s].dtype)
-
-            if sign == '+':
-                ind = signals[c, s]>thresholds[c, s]
-            else:
-                ind = signals[c, s]<thresholds[c, s]
-            sig[ind] = signals[c, s][ind]
-            sig[ind] /= abs(thresholds[c, s])
-            #~ sig[ind] /= thresholds[c, s]
-            combined.append(sig)
-        combined = np.sum(combined, axis = 0)
-        _sign = {'+':1, '-':-1}[sign]
+        if combined_sum:
+            combined = [ ]
+            for c in range(signals.shape[0]):
+                sig = np.zeros(signals[c, s].size, dtype = signals[c, s].dtype)
+                if sign == '+':
+                    ind = signals[c, s]>thresholds[c, s]
+                else:
+                    ind = signals[c, s]<thresholds[c, s]
+                sig[ind] = signals[c, s][ind]
+                sig[ind] /= abs(thresholds[c, s])
+                combined.append(sig)
+            sig_for_detection = np.sum(combined, axis = 0)
+            thresh = np.sign(thresholds[0, s])
+        else:
+            assert signals.shape[0]==1
+            sig_for_detection = signals[0, s]
+            thresh = thresholds[0, s]
+            
         if threshold_mode=='crossing':
-            pos_spike = get_all_crossing_threshold(combined, _sign, sign)
+            pos_spike = get_all_crossing_threshold(sig_for_detection, thresh, sign)
             #~ pos_spike = get_all_crossing_threshold(combined, 1., '+')
         elif threshold_mode=='peak':
-            pos_spike = get_all_peak_over_threshold(combined, _sign, sign, peak_span = peak_span)
+            pos_spike = get_all_peak_over_threshold(sig_for_detection, thresh, sign, peak_span = peak_span)
             #~ pos_spike = get_all_peak_over_threshold(combined, 1., '+', peak_span = peak_span)
         spike_index_array[s] = pos_spike
     return spike_index_array
